#!/usr/bin/env sh
# SPDX-License-Identifier: AGPL-3.0-or-later
# SPDX-FileCopyrightText: 2021-2024 JayVii <jayvii[AT]posteo[DOT]de>

# $1 - HTML Root
# $2 - prv/pub
# $3 - repo name
# $@ - optional list of refs, as given to post-update hook

# Error out if not all options are given
if [ -z "$3" ]; then
    echo "Usage:
git_deploy.sh \\
    \"/var/www/git.example.git\" \\
    \"pub\" \\
    \"stagit-jayvii.de\"
    "
    exit 1;
fi

for REF in $@; do

    # Git-Repository
    cd "${1}/${2}/${3}.git"

    # skip first three parameters
    if [ "$REF" = "$1" ] || [ "$REF" = "$2" ] || [ "$REF" = "$3" ]; then
        continue
    fi

    # fetch newest tag from given ref
    TAG=`git tag --contains $REF | tail -n 1 | awk '{ print $NF }'`

    # cycle through branches and tags
    if [ ! -z $TAG ]; then

        # create archive
        git archive ${TAG} . \
            --format=tar.gz \
            -o "${TAG}.tar.gz"

        # extract archive to temporary directory
        TMPDIR=`mktemp --directory`
        tar xfvz "${TAG}.tar.gz" --directory "${TMPDIR}/" > /dev/null

        # run deployment in temporary directory
        cd "$TMPDIR"
        make git-hook-deploy > /dev/null
        MAKE_STATUS=$?
        rm -r "$TMPDIR"

        # error handling
        if [ $MAKE_STATUS -gt 0 ]; then
            exit 1
        fi

        # Output for user
        echo "Version ${TAG} has been deployed"

    fi

done

